@@ -38,7 +38,7 @@ use HTTP::Status (RC_OK);
 
 #  Version information
 #
-$VERSION='1.005';
+$VERSION='1.007';
 
 
 #  Debug load
@@ -210,11 +210,16 @@ sub uri {
 
 
 sub debug {
-
-
+    
+    #  Stub
 }
 
 
+sub output_filters {
+    
+    #  Stub
+}
+
 sub AUTOLOAD {
 
     my ($r,$v)=@_;
